==> acquia_dam-1.0.0.tar.gz: acquia_dam/src/Client/AcquiaDamClientFactory.php <==
<?php

namespace Drupal\acquia_dam\Client;

use Drupal\acquia_dam\AcquiadamAuthService;
use Drupal\acquia_dam\Exception\DamClientException;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Session\AccountProxyInterface;
use GuzzleHttp\HandlerStack;

/**
 * Instantiates an Acquia DAM Client object.
 */
class AcquiaDamClientFactory {

  /**
   * The handler stack.
   *
   * @var \GuzzleHttp\HandlerStack
   */
  protected $stack;

  /**
   * The module extension list.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleList;

  /**
   * The cache backend.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  private $cacheBackend;

  /**
   * DAM auth service.
   *
   * @var \Drupal\acquia_dam\AcquiadamAuthService
   */
  protected $authService;

  /**
   * Current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Acquia DAM logger channel.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $damLoggerChannel;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * AcquiaDamClientFactory constructor.
   *
   * @param \GuzzleHttp\HandlerStack $stack
   *   Handler stack.
   * @param \Drupal\Core\Extension\ModuleExtensionList $module_list
   *   Module list service.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend.
   * @param \Drupal\acquia_dam\AcquiadamAuthService $authService
   *   User data service.
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   Current user.
   * @param \Drupal\Core\Logger\LoggerChannelInterface $loggerChannel
   *   Acquia DAM logger channel.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   */
  public function __construct(HandlerStack $stack, ModuleExtensionList $module_list, CacheBackendInterface $cache_backend, AcquiadamAuthService $authService, AccountProxyInterface $currentUser, LoggerChannelInterface $loggerChannel, TimeInterface $time, ConfigFactoryInterface $configFactory) {
    $this->stack = $stack;
    $this->moduleList = $module_list;
    $this->cacheBackend = $cache_backend;
    $this->authService = $authService;
    $this->currentUser = $currentUser;
    $this->damLoggerChannel = $loggerChannel;
    $this->time = $time;
    $this->configFactory = $configFactory;
  }

  /**
   * Returns a AcquiaDamClient instance using site token.
   *
   * @return \Drupal\acquia_dam\Client\AcquiaDamClient
   *   DAM client.
   *
   * @throws \Drupal\acquia_dam\Exception\DamClientException
   */
  public function getSiteClient(): AcquiaDamClient {
    return $this->getClient($this->authService->getSiteToken());
  }

  /**
   * Returns a AcquiaDamClient instance using the current user token.
   *
   * @return \Drupal\acquia_dam\Client\AcquiaDamClient
   *   DAM client.
   *
   * @throws \Drupal\acquia_dam\Exception\DamClientException
   */
  public function getUserClient(): AcquiaDamClient {
    return $this->getClient($this->getDamToken());
  }

  /**
   * Returns a AcquiaDamClient instance.
   *
   * @param string $token
   *   DAM token to authenticate with.
   *
   * @return \Drupal\acquia_dam\Client\AcquiaDamClient
   *   Client instance.
   *
   * @throws \Drupal\acquia_dam\Exception\DamClientException
   *   Throws when DAM token is missing from user data.
   */
  protected function getClient(string $token): AcquiaDamClient {
    if (!$token) {
      $this->damLoggerChannel->error('Could not get DAM token for client instantiation.');
      throw new DamClientException('Cannot get Acquia DAM token for client instantiation.');
    }

    $config = [
      'base_uri' => 'https://api.widencollective.com',
      'client-user-agent' => $this->getClientUserAgent(),
      'headers' => [
        'Authorization' => 'Bearer ' . $token,
        'Content-Type' => 'application/json',
      ],
      'handler' => $this->stack,
    ];

    $acquia_dam_config = $this->configFactory->get('acquia_dam.settings');

    return new AcquiaDamClient($this->cacheBackend, $this->time, $acquia_dam_config, $config);
  }

  /**
   * Get token from user data.
   *
   * @return string
   *   DAM token.
   */
  protected function getDamToken(): string {
    $acquia_dam_account = $this
      ->authService
      ->getUserData($this->currentUser->id());

    return $acquia_dam_account['acquia_dam_token'] ?? '';
  }

  /**
   * Returns Client's user agent.
   *
   * @return string
   *   User Agent.
   */
  protected function getClientUserAgent(): string {
    // Find out the module version in use.
    $module_info = $this->moduleList->getExtensionInfo('acquia_dam');
    $module_version = $module_info['version'] ?? '0.0.0';
    $drupal_version = \Drupal::VERSION;

    return 'AcquiaDam/' . $drupal_version . '-' . $module_version;
  }

}

==> acquia_dam-1.0.1.tar.gz: acquia_dam/src/Client/AcquiaDamClientFactory.php <==
<?php

namespace Drupal\acquia_dam\Client;

use Drupal\acquia_dam\AcquiadamAuthService;
use Drupal\acquia_dam\Exception\DamClientException;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Session\AccountProxyInterface;
use GuzzleHttp\HandlerStack;

/**
 * Instantiates an Acquia DAM Client object.
 */
class AcquiaDamClientFactory {

  /**
   * The handler stack.
   *
   * @var \GuzzleHttp\HandlerStack
   */
  protected $stack;

  /**
   * The module extension list.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleList;

  /**
   * The cache backend.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  private $cacheBackend;

  /**
   * DAM auth service.
   *
   * @var \Drupal\acquia_dam\AcquiadamAuthService
   */
  protected $authService;

  /**
   * Current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Acquia DAM logger channel.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $damLoggerChannel;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * AcquiaDamClientFactory constructor.
   *
   * @param \GuzzleHttp\HandlerStack $stack
   *   Handler stack.
   * @param \Drupal\Core\Extension\ModuleExtensionList $module_list
   *   Module list service.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend.
   * @param \Drupal\acquia_dam\AcquiadamAuthService $authService
   *   User data service.
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   Current user.
   * @param \Drupal\Core\Logger\LoggerChannelInterface $loggerChannel
   *   Acquia DAM logger channel.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   */
  public function __construct(HandlerStack $stack, ModuleExtensionList $module_list, CacheBackendInterface $cache_backend, AcquiadamAuthService $authService, AccountProxyInterface $currentUser, LoggerChannelInterface $loggerChannel, TimeInterface $time, ConfigFactoryInterface $configFactory) {
    $this->stack = $stack;
    $this->moduleList = $module_list;
    $this->cacheBackend = $cache_backend;
    $this->authService = $authService;
    $this->currentUser = $currentUser;
    $this->damLoggerChannel = $loggerChannel;
    $this->time = $time;
    $this->configFactory = $configFactory;
  }

  /**
   * Returns a AcquiaDamClient instance using site token.
   *
   * @return \Drupal\acquia_dam\Client\AcquiaDamClient
   *   DAM client.
   *
   * @throws \Drupal\acquia_dam\Exception\DamClientException
   */
  public function getSiteClient(): AcquiaDamClient {
    return $this->getClient($this->authService->getSiteToken());
  }

  /**
   * Returns a AcquiaDamClient instance using the current user token.
   *
   * @return \Drupal\acquia_dam\Client\AcquiaDamClient
   *   DAM client.
   *
   * @throws \Drupal\acquia_dam\Exception\DamClientException
   */
  public function getUserClient(): AcquiaDamClient {
    return $this->getClient($this->getDamToken());
  }

  /**
   * Returns a AcquiaDamClient instance.
   *
   * @param string $token
   *   DAM token to authenticate with.
   *
   * @return \Drupal\acquia_dam\Client\AcquiaDamClient
   *   Client instance.
   *
   * @throws \Drupal\acquia_dam\Exception\DamClientException
   *   Throws when DAM token is missing from user data.
   */
  protected function getClient(string $token): AcquiaDamClient {
    if (!$token) {
      $this->damLoggerChannel->error('Could not get DAM token for client instantiation.');
      throw new DamClientException('Cannot get Acquia DAM token for client instantiation.');
    }

    $config = [
      'base_uri' => 'https://api.widencollective.com',
      'client-user-agent' => $this->getClientUserAgent(),
      'headers' => [
        'Authorization' => 'Bearer ' . $token,
        'Content-Type' => 'application/json',
      ],
      'handler' => $this->stack,
    ];

    $acquia_dam_config = $this->configFactory->get('acquia_dam.settings');

    return new AcquiaDamClient($this->cacheBackend, $this->time, $acquia_dam_config, $config, $this->damLoggerChannel);
  }

  /**
   * Get token from user data.
   *
   * @return string
   *   DAM token.
   */
  protected function getDamToken(): string {
    $acquia_dam_account = $this
      ->authService
      ->getUserData($this->currentUser->id());

    return $acquia_dam_account['acquia_dam_token'] ?? '';
  }

  /**
   * Returns Client's user agent.
   *
   * @return string
   *   User Agent.
   */
  protected function getClientUserAgent(): string {
    // Find out the module version in use.
    $module_info = $this->moduleList->getExtensionInfo('acquia_dam');
    $module_version = $module_info['version'] ?? '0.0.0';
    $drupal_version = \Drupal::VERSION;

    return 'AcquiaDam/' . $drupal_version . '-' . $module_version;
  }

}
